@@ -1,6 +1,7 @@
 # DATABASE INFO
 # --------------
 
+
 # database folder
 DATABASE_FOLDER_NAME = "database"
 
@@ -26,3 +27,9 @@ DATABASE_INFO = [
 
 # general database info
 DATABASE_GENERAL_ITEMS = ["MW", "Tc", "Pc", "w", "dHf25", "dGf25"]
+DATABASE_GENERAL_ITEMS_FULL = [
+    ["molecular weight", "MW", "g/mol"], ["critical temperature", "Tc", "K"], [
+        "critical pressure", "Pc", "bar"],
+    ["acentric factor", "w", "-"], ["standard enthalpy of formation", "dHf25", "kJ/mol"], [
+        "Standard Gibbs free energy of formation", "dGf25", "kJ/mol"]
+]
